# Generated by Django 4.1.7 on 2023-03-09 05:31

from django.db import migrations, models
import email_log.models


class Migration(migrations.Migration):

    dependencies = [
        ("email_log", "0003_email_html_message_attachment"),
    ]

    operations = [
        migrations.AlterField(
            model_name="attachment",
            name="file",
            field=models.FileField(
                upload_to=email_log.models.get_attachment_path, verbose_name="file"
            ),
        ),
    ]
