# Generated by Django 5.1 on 2025-07-16 19:19

import django.core.serializers.json
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("email_log", "0005_email_bcc_recipients_email_cc_recipients"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="extra_headers",
            field=models.JSONField(
                default=dict, encoder=django.core.serializers.json.DjangoJSONEncoder
            ),
        ),
        migrations.AddField(
            model_name="email",
            name="reply_to",
            field=models.TextField(blank=True, default="", verbose_name="reply to"),
        ),
    ]
