# Generated by Django 4.2.13 on 2024-10-04 06:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("email_log", "0004_alter_attachment_file"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="bcc_recipients",
            field=models.TextField(blank=True, verbose_name="bcc recipients"),
        ),
        migrations.AddField(
            model_name="email",
            name="cc_recipients",
            field=models.TextField(blank=True, verbose_name="cc recipients"),
        ),
    ]
